==> daemonproxy-1.0.0.tar.bz2: daemonproxy-1.0.0/src/options_data.autogen.c <==
void set_opt_configfile(char **);
void set_opt_stdin(char **);
void opt_set_socket_path(char **);
void opt_set_daemonize(char **);
void set_opt_failsafe(char **);
void set_opt_exec_on_exit(char **);
void set_opt_fd_prealloc(char **);
void set_opt_svc_prealloc(char **);
void set_opt_mlockall(char **);
void set_opt_verbose(char **);
void set_opt_quiet(char **);
void show_help(char **);
void show_version(char **);

const struct option_table_entry_s option_table[]= {
	{ 'c', "config"          , "FILENAME", set_opt_configfile  , "Read command stream from FILENAME at startup" },
	{ 'i', "interactive"     , NULL      , set_opt_stdin       , "Use STDIN+STDOUT as a controller communication pipe" },
	{ 'S', "socket"          , "PATH"    , opt_set_socket_path , "Listen on PATH for controller connections" },
	{ 'D', "daemonize"       , NULL      , opt_set_daemonize   , "Fork into the background" },
	{  0 , "exit-guard"      , "INTEGER" , set_opt_failsafe    , "Guard against accidental termination" },
	{ 'E', "exit-exec"       , "TSV_ARGS", set_opt_exec_on_exit, "exec() args in any trappable exit scenario" },
	{  0 , "fd-pool"         , "N[xM]"   , set_opt_fd_prealloc , "Pre-allocate N named handles [of M bytes each]" },
	{  0 , "service-pool"    , "N[xM]"   , set_opt_svc_prealloc, "Pre-allocate N services [of M bytes each]" },
	{ 'M', "mlockall"        , NULL      , set_opt_mlockall    , "Call mlockall() after allocating structures" },
	{ 'v', "verbose"         , NULL      , set_opt_verbose     , "Enable another level of logging output" },
	{ 'q', "quiet"           , NULL      , set_opt_quiet       , "Suppress another level of logging output" },
	{  0 , "help"            , NULL      , show_help           , "Quick usage synopsis" },
	{  0 , "version"         , NULL      , show_version        , "Print complete version information" },
	{  0 , NULL, NULL, NULL, NULL }
};

==> daemonproxy-1.1.0.tar.bz2: daemonproxy-1.1.0/src/options_data.autogen.c <==
void set_opt_configfile(char **);
void set_opt_stdin(char **);
void opt_set_socket_path(char **);
void opt_set_daemonize(char **);
void set_opt_failsafe(char **);
void set_opt_exec_on_exit(char **);
void set_opt_fd_prealloc(char **);
void set_opt_svc_prealloc(char **);
void set_opt_mlockall(char **);
void set_opt_verbose(char **);
void set_opt_quiet(char **);
void show_help(char **);
void show_version(char **);

const struct option_table_entry_s option_table[]= {
	{ 'c', "config"          , "FILENAME", set_opt_configfile  , "Read command stream from FILENAME at startup" },
	{ 'i', "interactive"     , NULL      , set_opt_stdin       , "Use STDIN+STDOUT as a controller communication pipe" },
	{ 'S', "socket"          , "PATH"    , opt_set_socket_path , "Listen on PATH for controller connections" },
	{ 'D', "daemonize"       , NULL      , opt_set_daemonize   , "Fork into the background" },
	{  0 , "exit-guard"      , "INTEGER" , set_opt_failsafe    , "Guard against accidental termination" },
	{ 'E', "exit-exec"       , "TSV_ARGS", set_opt_exec_on_exit, "exec() args in any trappable exit scenario" },
	{  0 , "fd-pool"         , "N[xM]"   , set_opt_fd_prealloc , "Pre-allocate N named handles [of M bytes each]" },
	{  0 , "service-pool"    , "N[xM]"   , set_opt_svc_prealloc, "Pre-allocate N services [of M bytes each]" },
	{ 'M', "mlockall"        , NULL      , set_opt_mlockall    , "Call mlockall() after allocating structures" },
	{ 'v', "verbose"         , NULL      , set_opt_verbose     , "Enable another level of logging output" },
	{ 'q', "quiet"           , NULL      , set_opt_quiet       , "Suppress another level of logging output" },
	{ 'h', "help"            , NULL      , show_help           , "Quick usage synopsis" },
	{  0 , "version"         , NULL      , show_version        , "Print complete version information" },
	{  0 , NULL, NULL, NULL, NULL }
};
